@@ -55,6 +55,11 @@ CONNECTORS_REGISTRY = {
         'label': 'Facebook Insights',
         'logo': 'facebook_insights/facebook-insights.png',
     },
+    'Github': {
+        'connector': 'github.github_connector.GithubConnector',
+        'label': 'Github Connector',
+        'logo': 'github/GitHub_Logo.png',
+    },
     'GoogleAnalytics': {
         'connector': 'google_analytics.google_analytics_connector.GoogleAnalyticsConnector',
         'label': 'Google Analytics',
@@ -77,12 +82,12 @@ CONNECTORS_REGISTRY = {
     },
     'GoogleSheets': {
         'connector': 'google_sheets.google_sheets_connector.GoogleSheetsConnector',
-        'label': 'Google Sheets',
+        'label': 'Google Sheets (Legacy)',
         'logo': 'google_sheets/google-sheets.png',
     },
     'GoogleSheets2': {
         'connector': 'google_sheets_2.google_sheets_2_connector.GoogleSheets2Connector',
-        'label': 'Google Sheets Modified',
+        'label': 'Google Sheets',
         'logo': 'google_sheets/google-sheets.png',
     },
     'GoogleSpreadsheet': {
